@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Iterable, Union
+from typing import Iterable, Optional, Union
 
 from markdown_it import MarkdownIt
 
@@ -8,10 +8,18 @@ from mdformat.renderer import MDRenderer
 
 
 def text(
-    md: str, *, extensions: Iterable[str] = (), codeformatters: Iterable[str] = ()
+    md: str,
+    *,
+    options: Optional[dict] = None,
+    extensions: Iterable[str] = (),
+    codeformatters: Iterable[str] = (),
 ) -> str:
     """Format a Markdown string."""
     markdown_it = MarkdownIt(renderer_cls=MDRenderer)
+    # store reference labels in link/image tokens
+    markdown_it.options["store_labels"] = True
+    markdown_it.options["mdformat"] = options or {}
+
     markdown_it.options["parser_extension"] = []
     for name in extensions:
         plugin = mdformat.plugins.PARSER_EXTENSIONS[name]
@@ -26,6 +34,7 @@ def text(
 def file(
     f: Union[str, Path],
     *,
+    options: Optional[dict] = None,
     extensions: Iterable[str] = (),
     codeformatters: Iterable[str] = (),
 ) -> None:
@@ -40,6 +49,9 @@ def file(
         raise ValueError(f'Can not format "{f}". It is not a file.')
     original_md = f.read_text(encoding="utf-8")
     formatted_md = text(
-        original_md, extensions=extensions, codeformatters=codeformatters
+        original_md,
+        options=options,
+        extensions=extensions,
+        codeformatters=codeformatters,
     )
     f.write_text(formatted_md, encoding="utf-8")
