@@ -6,6 +6,7 @@ from typing import List
 from markdown_it.token import Token
 
 from mdformat.renderer._util import (
+    CONSECUTIVE_KEY,
     MARKERS,
     find_opening_token,
     is_tight_list,
@@ -89,24 +90,41 @@ def ordered_list_close(
     else:
         text = text.replace(MARKERS.BLOCK_SEPARATOR, "\n\n")
 
-    # Replace first MARKERS.LIST_ITEM with the starting number of the list.
-    # Replace following MARKERS.LIST_ITEMs with number one prefixed by zeros
-    # to make the marker of even length with the first one.
-    # E.g.
-    #   5321. This is the first list item
-    #   0001. Second item
-    #   0001. Third item
     opening_token = find_opening_token(tokens, idx)
     starting_number = opening_token.attrGet("start")
     if starting_number is None:
         starting_number = 1
-    first_item_marker = f"{starting_number}{number_marker} "
-    other_item_marker = (
-        "0" * (len(str(starting_number)) - 1) + "1" + number_marker + " "
-    )
-    indentation = " " * len(first_item_marker)
-    text = text.replace(MARKERS.LIST_ITEM, first_item_marker, 1)
-    text = text.replace(MARKERS.LIST_ITEM, other_item_marker)
+
+    if options.get("mdformat", {}).get(CONSECUTIVE_KEY, False):
+        # Replace MARKERS.LIST_ITEM with consecutive numbering,
+        # padded with zeros to make all markers of even length.
+        # E.g.
+        #   002. This is the first list item
+        #   003. Second item
+        #   ...
+        #   112. Last item
+        pad = len(str(text.count(MARKERS.LIST_ITEM) + starting_number - 1))
+        indentation = " " * (pad + len(f"{number_marker} "))
+        while MARKERS.LIST_ITEM in text:
+            number = str(starting_number).rjust(pad, "0")
+            text = text.replace(MARKERS.LIST_ITEM, f"{number}{number_marker} ", 1)
+            starting_number += 1
+    else:
+        # Replace first MARKERS.LIST_ITEM with the starting number of the list.
+        # Replace following MARKERS.LIST_ITEMs with number one prefixed by zeros
+        # to make the marker of even length with the first one.
+        # E.g.
+        #   5321. This is the first list item
+        #   0001. Second item
+        #   0001. Third item
+        first_item_marker = f"{starting_number}{number_marker} "
+        other_item_marker = (
+            "0" * (len(str(starting_number)) - 1) + "1" + number_marker + " "
+        )
+        indentation = " " * len(first_item_marker)
+        text = text.replace(MARKERS.LIST_ITEM, first_item_marker, 1)
+        text = text.replace(MARKERS.LIST_ITEM, other_item_marker)
+
     text = text.replace(MARKERS.INDENTATION, indentation)
 
     return text + MARKERS.BLOCK_SEPARATOR
